//! # Integers
//!
//! Fixed size and arbitrary precision, factorization into often-primes, nonzero signs.
pub mod factorization;
mod sign;
pub mod big;
